pub enum SlicePlanesAction {
None,
Add(String),
Remove(usize),
Modified(usize),
}Expand description
Actions that can be triggered from the slice planes UI.
Variants
None
No action.
Add(String)
Add a new slice plane with the given name.
Remove(usize)
Remove slice plane at the given index.
Modified(usize)
Settings for a plane were modified.