pub fn build_material_section(
ui: &mut Ui,
state: &mut MaterialLoadState,
) -> MaterialActionExpand description
Builds the material loading section in the left panel.
Returns a MaterialAction if the user requested loading.
pub fn build_material_section(
ui: &mut Ui,
state: &mut MaterialLoadState,
) -> MaterialActionBuilds the material loading section in the left panel.
Returns a MaterialAction if the user requested loading.